// GUI fr Kommandozeilenprogramme wie z.B. Tourieentferner.exe
// Copyright Andreas Niggemann, Speyer
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//
// Versionen:
//            01.03.2007 (BASIS)
//            04.03.2007 (Optionen -t und -o)
//
// Kommandozeilenparameter:
//   keine

unit teguia;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ShellApi, ExtDlgs, JPEG, FileCtrl;

type
  TteguiM1 = class(TForm)
    ListBox1: TListBox;
    startknopf: TButton;
    abbrknopf: TButton;
    hinzuknopf: TButton;
    entfknopf: TButton;
    OpenPictureDialog1: TOpenPictureDialog;
    ergebnis: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    verzausw: TButton;
    procedure FormCreate(Sender: TObject);
    procedure abbrknopfClick(Sender: TObject);
    procedure hinzuknopfClick(Sender: TObject);
    procedure FormKeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure entfknopfClick(Sender: TObject);
    procedure startknopfClick(Sender: TObject);
    procedure Label2Click(Sender: TObject);
    procedure ergebnisDblClick(Sender: TObject);
    procedure ergebnisChange(Sender: TObject);
  private
    { Private-Deklarationen }
    procedure initall;
    procedure resultat;
    procedure WMDROPFILES (var Msg: TMessage); message WM_DROPFILES;
  public
    { Public-Deklarationen }
  end;

var
  teguiM1: TteguiM1;
  zielprogramm : string;
  erg_geaendert : boolean;

implementation

{$R *.dfm}
procedure TteguiM1.resultat;
var res_fname, res_verz : string;
begin
  if ListBox1.Items.Count = 0 then // alles auf Anfang wenn Liste geleert
  begin
    ergebnis.Text := '';
    erg_geaendert := false;
  end;
  if not erg_geaendert then // Ergebnis wurde nicht gendert
  begin
    if Pos('TOURIEENTF',ANSIUpperCase(zielprogramm)) > 0 then
    begin
      if ListBox1.Items.Count > 0 then
      begin
        res_verz := ExtractFilePath(ExpandFileName(ListBox1.Items[0]));
        res_fname := res_verz + '\..\out.jpg';
        res_fname := ExpandFileName(res_fname);
        if ergebnis.Text <> res_fname then
          ergebnis.Text := res_fname;
      end;
    end;
  end;
end;

procedure TteguiM1.WMDROPFILES (var Msg: TMessage);
var i, anzahl, size: integer;
  Dateiname: PChar;
begin
  inherited;
  Dateiname := '';
  anzahl := DragQueryFile(Msg.WParam, $FFFFFFFF, Dateiname, 255);
  for i := 0 to (anzahl - 1) do
  begin
    size := DragQueryFile(Msg.WParam, i , nil, 0) + 1;
    Dateiname:= StrAlloc(size);
    DragQueryFile(Msg.WParam,i , Dateiname, size);
    ListBox1.items.add(StrPas(Dateiname));
    StrDispose(Dateiname);
  end;
  DragFinish(Msg.WParam);
  resultat;
end;

// Anlegen der Arbeitsverzeichnisse
procedure TteguiM1.initall;
var fname, Directory, Mask : string;
    SR: TSearchRec;
begin
  erg_geaendert := false;
  zielprogramm := '';
  ergebnis.Text := '';
  Directory := ExtractFileDir(ExpandFileName(ParamStr(0))) + '\';
  Mask := '*.exe';
  if FindFirst(Directory + Mask, faAnyFile and not faDirectory, SR) = 0 then try
    repeat
      fname := Directory + SR.Name;
      if SR.Name <> ExtractFileName(ParamStr(0)) then
        zielprogramm := SR.Name;
    until FindNext(SR) <> 0;
  finally
    FindClose(SR);
  end;
  if zielprogramm <> '' then
    teguiM1.startknopf.Hint := zielprogramm + ' starten';
end;

procedure TteguiM1.FormCreate(Sender: TObject);
begin
  DragAcceptFiles(ListBox1.Handle, true);
  initall; // Arbeitsverzeichnis anlegen etc.
end;

// Programm einstarten
function ExecAndWait(const Filename, Params: string;
                     WindowState: word): boolean;
var
  SUInfo: TStartupInfo;
  ProcInfo: TProcessInformation;
  CmdLine: string;
begin
  CmdLine := '"' + Filename + '" ' + Params;
  FillChar(SUInfo, SizeOf(SUInfo), #0);
  with SUInfo do begin
    cb := SizeOf(SUInfo);
    dwFlags := STARTF_USESHOWWINDOW;
    wShowWindow := WindowState;
  end;
  Result := CreateProcess(NIL, PChar(CmdLine), NIL, NIL, FALSE,
                          CREATE_NEW_CONSOLE or
                          NORMAL_PRIORITY_CLASS, NIL,
                          PChar(ExtractFilePath(Filename)),
                          SUInfo, ProcInfo);
  if Result then
    WaitForSingleObject(ProcInfo.hProcess, INFINITE);
end;

// Dateien verarbeiten
procedure TteguiM1.startknopfClick(Sender: TObject);
var verz, touri_param, param : string;
    i : integer;
begin
  param := '';
  touri_param := '';
  for i := 0 to ListBox1.Count-1 do
    param := param + '"' + ListBox1.Items[i] + '" ';
  if param <> '' then // Was da, also Programm starten
  begin
    if Pos('TOURIEENTF',ANSIUpperCase(zielprogramm)) > 0 then
    begin
      if Pos('TIF',ANSIUpperCase(ExtractFileExt(ergebnis.Text))) > 0 then
        touri_param := '-t ';
      if ergebnis.Text <> '' then
        touri_param := touri_param + '-o "' + ergebnis.Text + '" ';
    end;
    verz := ExtractFilePath(ExpandFileName(ParamStr(0)));
    ExecAndWait(verz + zielprogramm,touri_param + param,SW_SHOW);
    if ergebnis.Text <> '' then
    begin
      if FileExists(ergebnis.Text) then
        ShellExecute(Application.Handle,'open',PChar(ergebnis.Text),'','',SW_SHOW)
      else
        ShowMessage(ergebnis.Text + ' nicht vorhanden!');
    end;
  end;
end;

// Programm beenden
procedure TteguiM1.abbrknopfClick(Sender: TObject);
begin
  Application.Terminate;
end;

// Datei hinzufgen
procedure TteguiM1.hinzuknopfClick(Sender: TObject);
var fname : string;
begin
  with OpenPictureDialog1 do
  begin
    if Execute then // Datei(en) ausgewhlt
    begin
      fname := FileName;
      ListBox1.Items.AddStrings(Files);
    end;
  end;
  resultat;
end;

// Datei(en) aus der Liste entfernen
procedure TteguiM1.entfknopfClick(Sender: TObject);
begin
  if ListBox1.SelCount > 0 then
    ListBox1.DeleteSelected;
  resultat;
end;

// Taste gedrckt
procedure TteguiM1.FormKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if Key = VK_DELETE then // Eintrge entfernen
    entfknopfClick(Sender);
  if Key = VK_ESCAPE then // Programm beende
    Application.Terminate;
end;

procedure TteguiM1.Label2Click(Sender: TObject);
begin
  ShellExecute(Application.Handle,'open','http://www.smssend.de','','',SW_SHOW)
end;

// Auswahl Zielverzeichnis
procedure TteguiM1.ergebnisDblClick(Sender: TObject);
var dir, fname : string;
begin
 dir := '.\';
 fname := '';
 if ergebnis.Text <> '' then
 begin
   dir := ExtractFileDir(ergebnis.Text);
   fname := ExtractFileName(ergebnis.Text);
 end;
 if SelectDirectory(dir, [sdAllowCreate, sdPerformCreate, sdPrompt],0) then
    ergebnis.Text := dir + '\' + fname;
end;

procedure TteguiM1.ergebnisChange(Sender: TObject);
begin
  erg_geaendert := true;
end;

end.


